@@ -34,10 +34,10 @@
 
 #include <KCodecs/KCodecs>
 
-#include <QtCore/QTextCodec>
-#include <QtCore/QMap>
-#include <QtCore/QStringList>
-#include <QtCore/QUrl>
+#include <QTextCodec>
+#include <QMap>
+#include <QStringList>
+#include <QUrl>
 
 #include <ctype.h> // for isdigit
 #include <cassert>
@@ -451,6 +451,9 @@ bool parseGenericQuotedString(const char *&scursor, const char *const send,
                 scursor = oldscursor;
             }
             // fall through
+#if QT_VERSION >= QT_VERSION_CHECK(5,8,0)
+        Q_FALLTHROUGH();
+#endif
         }
         default:
             KMIME_WARN_IF_8BIT(ch);
@@ -634,6 +637,9 @@ bool parsePhrase(const char *&scursor, const char *const send,
                 // parse as atom:
                 scursor = oldscursor;
             }
+#if QT_VERSION >= QT_VERSION_CHECK(5,8,0)
+        Q_FALLTHROUGH();
+#endif
         // fall though...
 
         default: //atom
